'use strict';

const AWS = require('aws-sdk');
const errors = require('../../common/errors');

const dynamodb = new AWS.DynamoDB.DocumentClient();

/**
 * @api {get} /journeys List all journeys
 * @apiGroup Journeys
 *
 * @apiSuccess {Object[]} journeys                         List of journeys
 * @apiSuccess {String}   journeys.vessel_name             Vessel name.
 * @apiSuccess {Number}   journeys.estimated_arrival_time  Estimated arrival time.
 * @apiSuccess {Object}   journeys.last_port               Last port information.
 * @apiSuccess {String}   journeys.last_port.city          Last port name.
 * @apiSuccess {String}   journeys.last_port.country       Last port country.
 * @apiSuccess {Object}   journeys.next_port               Next port information.
 * @apiSuccess {String}   journeys.next_port.city          Next port name.
 * @apiSuccess {String}   journeys.next_port.country       Next port country.
 * @apiSuccess {Number}   journeys.status                  Journey status.
 * @apiSuccess {Number}   journeys.created_at              Timestamp of creation.
 * @apiSuccess {Number}   journeys.updated_at              Timestamp of last update.
 * 
 * @apiError (Error 5xx) InternalServerError  Couldn't fetch journey list
 */
module.exports.list = (event, context, callback) => {
  const params = {
    TableName: process.env.JOURNEYS_TABLE
  };

  
  dynamodb.scan(params, (error, result) => {
    if (error) {
      callback(null, errors.internalServerError("Couldn't fetch journey list"));
      return;
    }

    const response = {
      statusCode: 200,
      body: JSON.stringify(result.Items)
    };

    callback(null, response);
  });
};