'use strict';

const AWS = require('aws-sdk');
const errors = require('../../common/errors');

const dynamodb = new AWS.DynamoDB.DocumentClient();

/**
 * @api {get} /vessels List all vessels
 * @apiGroup Vessels
 *
 * @apiSuccess {Object[]} vessels                    List of vessels
 * @apiSuccess {String}   vessels.name               Name of the vessel.
 * @apiSuccess {Object}   vessels.home_port          Home port information.
 * @apiSuccess {String}   vessels.home_port.city     Home port name.
 * @apiSuccess {String}   vessels.home_port.country  Home port country.
 * @apiSuccess {Number}   vessels.created_at         Timestamp of creation.
 * @apiSuccess {Number}   vessels.updated_at         Timestamp of last update.
 * 
 * @apiError (Error 5xx) InternalServerError  Couldn't fetch vessel list
 */
module.exports.list = (event, context, callback) => {
  const params = {
    TableName: process.env.VESSELS_TABLE
  };

  /* Scan database for vessels and return */
  dynamodb.scan(params, (error, result) => {
    if (error) {
      callback(null, errors.internalServerError("Couldn't fetch vessel list"));
      return;
    }

    const response = {
      statusCode: 200,
      body: JSON.stringify(result.Items)
    };

    callback(null, response);
  });
};
